SmartLinkData class

Immutable deep link payload delivered to the app.

Constructors

SmartLinkData({required Uri uri, required String path, required Map<String, String> queryParams, required bool isDeferred, required SmartLinkSource source, DateTime? timestamp})

Properties

hashCode int
The hash code for this object.
no setteroverride
isDeferred bool
final
path String
final
queryParams Map<String, String>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
source SmartLinkSource
final
timestamp DateTime
final
uri Uri
final

Methods

hasParam(String key) bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
param(String key) String?
paramInt(String key) int?
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override