SmartLinkParser class

Parses URIs and install-referrer payloads into SmartLinkData.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

encodeReferrerPayload({required String path, Map<String, String>? params, int? timestampMs}) String
Encodes deferred payload for Play Store referrer (Base64 URL-safe JSON).
fromMap(Map? map) SmartLinkData?
fromReferrerPayload(String payload) SmartLinkData?
Decodes a deferred install referrer payload (Base64 JSON or plain JSON).
fromUri(Uri uri, {SmartLinkSource source = SmartLinkSource.unknown, bool isDeferred = false}) SmartLinkData?